@@ -347,6 +347,7 @@ class ProgressBar():
         self.pbar = None
 
     def __call__(self, block_num, block_size, total_size):
+        import progressbar
         if not self.pbar:
             self.pbar=progressbar.ProgressBar(maxval=total_size)
             self.pbar.start()
@@ -368,6 +369,11 @@ def check_weight_files():
         input_url = "https://github.com/abysslover/deepparcellation/releases/download/v1.0.0/weights.tar.gz"
         import urllib.request
         urllib.request.urlretrieve(input_url, output_path, ProgressBar())
+    print(f"[check_weight_files] Uncompress weights: {output_path}")
+    import tarfile    
+    with tarfile.open(output_path, "r") as tar:
+        tar.extractall(path=parent_dir)
+    os.remove(output_path)
 
 def main():
     check_weight_files()
